package com.bweb.controller.item;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.config.MathConfig;
import com.hfkj.entity.EnItem;
import com.hfkj.entity.EnOilDepots;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.item.EnOilDepotsService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value="/enOilDepots")
@Api(value="项目油管管理")
public class EnOilDepotsController {

    Logger log = LoggerFactory.getLogger(EnOilDepotsController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private EnOilDepotsService enOilDepotsService;


    @RequestMapping(value="/create",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "创建油库")
    public ResponseData create(@RequestBody EnOilDepots body) {
        try {
            if (body == null
                    || body.getItemId() == null
                    || body.getLatitude() == null
                    || body.getLongitude() ==  null
                    || body.getWarningLevel() ==  null
                    || StringUtils.isBlank(body.getContactInfo())
                    || StringUtils.isBlank(body.getOilDepotName())
                    || StringUtils.isBlank(body.getContactPerson())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);

            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type1.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }

            body.setUpdateTime(new Date());
            body.setOilDepotNo(MathConfig.generateEncoding(9));
            body.setCreateTime(new Date());
            body.setCreateUser(sessionModel.getAccount().getId());
            body.setStatus(2);
            body.setCapacity(BigDecimal.ZERO);
            body.setCurrentStock(BigDecimal.ZERO);
            body.setCreateUserName(sessionModel.getAccount().getUserName());
            enOilDepotsService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改油库")
    public ResponseData update(@RequestBody EnOilDepots body) {
        try {
            if (body == null
                    || body.getId() == null
                    || body.getItemId() == null
                    || body.getLatitude() == null
                    || body.getLongitude() ==  null
                    || body.getWarningLevel() ==  null
                    || StringUtils.isBlank(body.getOilDepotName())
                    || StringUtils.isBlank(body.getContactPerson())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);

            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type1.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }
            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnOilDepots enOilDepots = enOilDepotsService.queryDetailByMap(map);

            if (enOilDepots == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "油库不存在");
            }

            enOilDepots.setItemId(body.getItemId());
            enOilDepots.setLatitude(body.getLatitude());
            enOilDepots.setLongitude(body.getLongitude());
            enOilDepots.setWarningLevel(body.getWarningLevel());
            enOilDepots.setOilDepotName(body.getOilDepotName());
            enOilDepots.setContactPerson(body.getContactPerson());
            enOilDepots.setUpdateTime(new Date());
            enOilDepots.setUpdateTime(new Date());
            enOilDepots.setUpdateUser(sessionModel.getAccount().getId());
            enOilDepots.setUpdateUserName(sessionModel.getAccount().getUserName());
            enOilDepotsService.update(enOilDepots);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/updateStatus",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改状态")
    public ResponseData updateStatus(@RequestBody EnItem body) {
        try {
            if (body == null
                    || body.getId() == null
                    || body.getStatus() == null
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnOilDepots enOilDepots = enOilDepotsService.queryDetailByMap(map);

            if (enOilDepots == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "油库不存在");
            }

            enOilDepots.setStatus(body.getStatus());
            enOilDepots.setUpdateTime(new Date());
            enOilDepots.setUpdateUser(sessionModel.getAccount().getId());
            enOilDepots.setUpdateUserName(sessionModel.getAccount().getUserName());
            enOilDepotsService.update(enOilDepots);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value="/deleteItem",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData deleteGoods(@RequestParam(value = "id" , required = false) Long id) {
        try {

            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",id);
            map.put("createUser" , sessionModel.getAccount().getId());

            EnOilDepots enOilDepots = enOilDepotsService.queryDetailByMap(map);
            if (enOilDepots == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "油库不存在");
            }

            enOilDepotsService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value="/queryDetail",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询详情")
    public ResponseData queryDetail(@RequestParam(value = "id" , required = false) Long id) {
        try {

            return ResponseMsgUtil.success(enOilDepotsService.queryDetail(id));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询项目列表")
    public ResponseData queryList(@RequestParam(value = "itemId" , required = false) Long itemId,
                                  @RequestParam(value = "oilDepotNo" , required = false) String oilDepotNo,
                                  @RequestParam(value = "oilDepotName" , required = false) String oilDepotName,
                                  @RequestParam(value = "status" , required = false) Integer status,
                                  @RequestParam(value = "contactPerson" , required = false) String contactPerson,
                                  @RequestParam(value = "contactInfo" , required = false) String contactInfo,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("contactInfo", contactInfo);
            param.put("itemId", itemId);
            param.put("oilDepotNo", oilDepotNo);
            param.put("oilDepotName", oilDepotName);
            param.put("contactPerson", contactPerson);
            param.put("status", status);
            param.put("createUser", sessionModel.getAccount().getId());

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(enOilDepotsService.getList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
