package com.bweb.controller.item;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.EnItemSegments;
import com.hfkj.entity.EnSerCompanySgRel;
import com.hfkj.entity.EnServiceCompany;
import com.hfkj.entity.EnTransportCompany;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.item.EnItemSegmentsService;
import com.hfkj.service.item.EnSerCompanySgRelService;
import com.hfkj.service.item.EnServiceCompanyService;
import com.hfkj.service.item.EnTransportCompanyService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value="/enTransportCompany")
@Api(value="运输公司管理")
public class EnTransportCompanyController {
    Logger log = LoggerFactory.getLogger(EnTransportCompanyController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private EnTransportCompanyService enTransportCompanyService;

    @RequestMapping(value="/create",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "创建运输公司")
    public ResponseData create(@RequestBody EnTransportCompany body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getName())
                    || StringUtils.isBlank(body.getContactInfo())
                    || StringUtils.isBlank(body.getAddress())
                    || StringUtils.isBlank(body.getPerson())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type1.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }

            body.setUpdateTime(new Date());
            body.setCreateTime(new Date());
            body.setCreateUser(sessionModel.getAccount().getId());
            body.setStatus(1);
            body.setCreateUserName(sessionModel.getAccount().getUserName());
            enTransportCompanyService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改运输公司")
    public ResponseData update(@RequestBody EnTransportCompany body) {
        try {
            if (body == null
                    || body.getId() == null
                    || StringUtils.isBlank(body.getName())
                    || StringUtils.isBlank(body.getAddress())
                    || StringUtils.isBlank(body.getPerson())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type1.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnTransportCompany enTransportCompany = enTransportCompanyService.queryDetailByMap(map);
            if (enTransportCompany == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "服务公司不存在");
            }

            enTransportCompany.setName(body.getName());
            enTransportCompany.setAddress(body.getAddress());
            enTransportCompany.setPerson(body.getPerson());

            enTransportCompany.setUpdateTime(new Date());
            enTransportCompany.setUpdateUser(sessionModel.getAccount().getId());
            enTransportCompany.setUpdateUserName(sessionModel.getAccount().getUserName());
            enTransportCompanyService.update(enTransportCompany);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/delete",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData delete(@RequestParam(value = "id" , required = false) Long id) {
        try {

            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",id);
            map.put("createUser" , sessionModel.getAccount().getId());

            EnTransportCompany enTransportCompany = enTransportCompanyService.queryDetailByMap(map);
            if (enTransportCompany == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "项目不存在");
            }

            enTransportCompanyService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value="/queryDetail",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询详情")
    public ResponseData queryDetail(@RequestParam(value = "id" , required = false) Long id) {
        try {

            return ResponseMsgUtil.success(enTransportCompanyService.queryDetail(id));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询项目列表")
    public ResponseData queryList(@RequestParam(value = "name" , required = false) String name,
                                  @RequestParam(value = "address" , required = false) String address,
                                  @RequestParam(value = "status" , required = false) Integer status,
                                  @RequestParam(value = "person" , required = false) String person,
                                  @RequestParam(value = "contactInfo" , required = false) String contactInfo,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("name", name);
            param.put("contactInfo", contactInfo);
            param.put("address", address);
            param.put("person", person);
            param.put("status", status);
            param.put("createUser", sessionModel.getAccount().getId());

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(enTransportCompanyService.getList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


}
