package com.hfkj.service.item.impl;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.MD5Util;
import com.hfkj.dao.EnItemMapper;
import com.hfkj.entity.EnItem;
import com.hfkj.entity.EnItemExample;
import com.hfkj.entity.SecUser;
import com.hfkj.service.SecRoleService;
import com.hfkj.service.SecUserService;
import com.hfkj.service.item.EnItemService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import com.hfkj.sysenum.SecUserStatusEnum;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("enItemService")
public class EnItemServiceImpl implements EnItemService {

    @Resource
    private EnItemMapper enItemMapper;
    @Resource
    private SecUserService secUserService;

    @Override
    @Transactional(propagation= Propagation.REQUIRES_NEW,rollbackFor= {RuntimeException.class})
    public void create(EnItem enItem) throws Exception  {

        enItemMapper.insert(enItem);
        if (secUserService.getDetailByLoginName(enItem.getContactInfo()) != null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "登录账户已存在，请更换");
        }

        SecUser secUser = new SecUser();
        secUser.setUserName(enItem.getProjectName());
        secUser.setLoginName(enItem.getContactInfo());
        secUser.setPassword(MD5Util.encode("123456".getBytes()));
        secUser.setTelephone(enItem.getContactInfo());
        secUser.setRoleId(1026L);
        secUser.setObjectType(SecUserObjectTypeEnum.type2.getCode());
        secUser.setObjectId(enItem.getId());
        secUser.setStatus(SecUserStatusEnum.status1.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public void update(EnItem enItem) {
        enItemMapper.updateByPrimaryKey(enItem);
        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type2, enItem.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setUserName(enItem.getProjectName());
        secUserService.editUser(secUser);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        EnItem enItem = queryDetail(id);
        if (fullDelete) {
            enItemMapper.deleteByPrimaryKey(id);
        } else {
            enItem.setStatus(0);
            enItem.setUpdateTime(new Date());
            update(enItem);
        }

        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type2, enItem.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setStatus(SecUserStatusEnum.status0.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public EnItem queryDetail(Long id) {
        return enItemMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnItem queryDetailByMap(Map<String, Object> map) {
        EnItemExample example = new EnItemExample();
        EnItemExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectAddress"))) {
            criteria.andProjectAddressLike("%"+MapUtils.getString(map, "projectAddress")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectLeader"))) {
            criteria.andProjectLeaderLike("%"+MapUtils.getString(map, "projectLeader")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectName"))) {
            criteria.andProjectNameLike("%"+MapUtils.getString(map, "projectName")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {

            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        example.setOrderByClause("create_time desc");

        List<EnItem> enItems = enItemMapper.selectByExample(example);

        return enItems.isEmpty() ? null : enItems.get(0);

    }

    @Override
    public List<EnItem> getList(Map<String, Object> map) {
        EnItemExample example = new EnItemExample();
        EnItemExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectAddress"))) {
            criteria.andProjectAddressLike("%"+MapUtils.getString(map, "projectAddress")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectLeader"))) {
            criteria.andProjectLeaderLike("%"+MapUtils.getString(map, "projectLeader")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectName"))) {
            criteria.andProjectNameLike("%"+MapUtils.getString(map, "projectName")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {

            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }



        example.setOrderByClause("create_time desc");

        return enItemMapper.selectByExample(example);
    }
}
